"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const Types_1 = require("frontblock-generic/Types");
const Logger = require("log4js");
const Plugin_1 = require("frontblock-generic/Plugin");
Logger.configure({
    appenders: {
        "frontblock-api-client": { type: 'stdout' },
    },
    categories: {
        default: { appenders: ['frontblock-api-client'], level: 'debug' }
    }
});
const logger = Logger.getLogger("frontblock-api-client");
const bsock = require('bsock');
/**
 * Frontblock api connection lib
 */
class FrontblockApiClient extends Plugin_1.ConfigLoader {
    constructor() {
        super("FrontblockApiClient");
        this.started = false;
        this.apikey = "";
    }
    initConfig() {
        return {
            apiHost: "api.testnet.frontblock.me",
            apiKey: "",
            apiPort: 10001,
            tls: false
        };
    }
    async consume(apikey, uid, callback) {
        const r = await this.socket.call("consume", apikey, uid);
        const res = Types_1.parseSubResponse(r);
        if (res instanceof Types_1.SubscriptionResponse) {
            this.socket.hook(res.uid, (tx) => {
                const deserialized = JSON.parse(tx);
                callback(deserialized);
            });
        }
        return res;
    }
    async quit(apikey, consumerUid) {
        const r = await this.socket.call("quit", apikey, consumerUid);
        const res = Types_1.parseResponse(r);
        return res;
    }
    async subscribe(apikey, coin, account) {
        const r = await this.socket.call("subscribe", apikey, coin, account);
        const res = Types_1.parseSubResponse(r);
        return res;
    }
    async subsume(apikey, coin, account, callback) {
        const r = await this.socket.call("subsume", apikey, coin, account);
        const res = Types_1.parseSubResponse(r);
        if (res instanceof Types_1.SubscriptionResponse) {
            this.socket.hook(res.uid, (tx) => {
                const deserialized = JSON.parse(tx);
                callback(deserialized);
            });
        }
        return res;
    }
    async unsubscribe(apikey, uid) {
        const r = await this.socket.call('unsubscribe', apikey, uid);
        const res = Types_1.parseResponse(r);
        if (res instanceof Types_1.SuccessResponse)
            this.socket.unhook(uid);
        return res;
    }
    async getPluginList() {
        return await this.socket.call('getPluginList');
    }
    connect() {
        if (this.started) {
            logger.warn("FrontblockApiClient has already been started. Ignoring");
            return;
        }
        logger.info("Starting apiClient with ", this.conf);
        this.socket = bsock.connect(this.conf.apiPort, this.conf.apiHost, this.conf.tls != null ? this.conf.tls : false);
        this.started = true;
    }
    disconnect() {
        if (!this.started) {
            logger.warn("FrontblockApiClient has not been started. Ignoring");
            return;
        }
        this.socket.close();
    }
}
exports.default = FrontblockApiClient;
